package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.THealthSolve;

/**
 * 健康告警处理Mapper接口
 * 
 * @author zhengjie
 * @date 2023-09-09
 */
public interface THealthSolveMapper 
{
    /**
     * 查询健康告警处理
     * 
     * @param id 健康告警处理主键
     * @return 健康告警处理
     */
    public THealthSolve selectTHealthSolveById(Integer id);

    /**
     * 查询健康告警处理列表
     * 
     * @param tHealthSolve 健康告警处理
     * @return 健康告警处理集合
     */
    public List<THealthSolve> selectTHealthSolveList(THealthSolve tHealthSolve);

    /**
     * 新增健康告警处理
     * 
     * @param tHealthSolve 健康告警处理
     * @return 结果
     */
    public int insertTHealthSolve(THealthSolve tHealthSolve);

    /**
     * 修改健康告警处理
     * 
     * @param tHealthSolve 健康告警处理
     * @return 结果
     */
    public int updateTHealthSolve(THealthSolve tHealthSolve);

    /**
     * 删除健康告警处理
     * 
     * @param id 健康告警处理主键
     * @return 结果
     */
    public int deleteTHealthSolveById(Integer id);

    /**
     * 批量删除健康告警处理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTHealthSolveByIds(Integer[] ids);
}
