package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.TRailSolve;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.THealthSolve;
import com.ruoyi.system.service.ITHealthSolveService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 健康告警处理Controller
 * 
 * @author zhengjie
 * @date 2023-09-09
 */
@RestController
@RequestMapping("/system/healthsolve")
public class THealthSolveController extends BaseController
{
    @Autowired
    private ITHealthSolveService tHealthSolveService;

    /**
     * 查询健康告警处理列表
     */
    @PreAuthorize("@ss.hasPermi('system:healthsolve:list')")
    @GetMapping("/list")
    public TableDataInfo list(THealthSolve tHealthSolve)
    {
        startPage();
        List<THealthSolve> list = tHealthSolveService.selectTHealthSolveList(tHealthSolve);
        for (THealthSolve salve : list){
            if (StringUtils.isNull(salve.getSolve_status())){
                salve.setSolve_status(0);
            }
            salve.setAlarmMsg("健康告警求助：" + salve.getName() + "于" + DateUtils.parseDateToStr(DateUtils.YYYY_MM_DD_HH_MM_SS,salve.getCreatetime()) + "发起健康告警求助");
        }
        return getDataTable(list);
    }

    /**
     * 导出健康告警处理列表
     */
    @PreAuthorize("@ss.hasPermi('system:healthsolve:export')")
    @Log(title = "健康告警处理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, THealthSolve tHealthSolve)
    {
        List<THealthSolve> list = tHealthSolveService.selectTHealthSolveList(tHealthSolve);
        ExcelUtil<THealthSolve> util = new ExcelUtil<THealthSolve>(THealthSolve.class);
        util.exportExcel(response, list, "健康告警处理数据");
    }

    /**
     * 获取健康告警处理详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:healthsolve:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(tHealthSolveService.selectTHealthSolveById(id));
    }

    /**
     * 新增健康告警处理
     */
    @PreAuthorize("@ss.hasPermi('system:healthsolve:add')")
    @Log(title = "健康告警处理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody THealthSolve tHealthSolve)
    {
        return toAjax(tHealthSolveService.insertTHealthSolve(tHealthSolve));
    }

    /**
     * 修改健康告警处理
     */
    @PreAuthorize("@ss.hasPermi('system:healthsolve:edit')")
    @Log(title = "健康告警处理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody THealthSolve tHealthSolve)
    {
        return toAjax(tHealthSolveService.updateTHealthSolve(tHealthSolve));
    }

    /**
     * 删除健康告警处理
     */
    @PreAuthorize("@ss.hasPermi('system:healthsolve:remove')")
    @Log(title = "健康告警处理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(tHealthSolveService.deleteTHealthSolveByIds(ids));
    }
}
